@@ -747,7 +747,11 @@ def bronze_to_silver(
                     .format('delta')\
                     .mode('append')\
                     .saveAsTable("cortex.data_governance_quality.tables")
-                
+                print(f""" 
+                catalog_name : {catalog_name},
+                output_db_table : {output_db_table},
+                description : {tbl_properties.get('cortex.description')},
+                """)
                 set_comment_table(catalog_name, output_db_table, tbl_properties.get('cortex.description'))
 
             except Exception as e:
